@@ -4,11 +4,12 @@ use crate::client::subscription::SubscriptionTx;
 use crate::client::sync::{unbounded, ChannelRx, ChannelTx};
 use crate::client::transport::router::SubscriptionRouter;
 use crate::event::Event;
+use crate::prelude::*;
 use crate::query::Query;
 use crate::utils::uuid_str;
 use crate::{Client, Error, Method, Request, Response, Subscription, SubscriptionClient};
+use alloc::collections::BTreeMap as HashMap;
 use async_trait::async_trait;
-use std::collections::HashMap;
 
 /// A mock client implementation for use in testing.
 ///
@@ -31,8 +32,7 @@ use std::collections::HashMap;
 ///   }
 /// }"#;
 ///
-/// #[tokio::main]
-/// async fn main() {
+/// tokio_test::block_on(async {
 ///     let matcher = MockRequestMethodMatcher::default()
 ///         .map(Method::AbciInfo, Ok(ABCI_INFO_RESPONSE.to_string()));
 ///     let (client, driver) = MockClient::new(matcher);
@@ -44,7 +44,7 @@ use std::collections::HashMap;
 ///
 ///     client.close();
 ///     driver_hdl.await.unwrap();
-/// }
+/// });
 /// ```
 #[derive(Debug)]
 pub struct MockClient<M: MockRequestMatcher> {
