@@ -1,8 +1,9 @@
 //! Ordering of paginated RPC responses.
 
+use crate::prelude::*;
 use crate::Error;
+use core::str::FromStr;
 use serde::{Deserialize, Serialize};
-use std::str::FromStr;
 
 /// Ordering of paginated RPC responses.
 #[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
@@ -23,7 +24,7 @@ impl FromStr for Order {
         match s {
             "asc" => Ok(Self::Ascending),
             "desc" => Ok(Self::Descending),
-            _ => Err(Error::invalid_params(&format!(
+            _ => Err(Error::invalid_params(format!(
                 "invalid order type: {} (must be \"asc\" or \"desc\")",
                 s
             ))),
