@@ -3,7 +3,7 @@
 use std::{fs, path::PathBuf};
 use tendermint::abci::Code;
 
-use std::str::FromStr;
+use core::str::FromStr;
 use tendermint::vote;
 use tendermint_rpc::endpoint::consensus_state::RoundVote;
 use tendermint_rpc::{
